Index: trunk/autoquest-core-tasktrees/src/main/java/de/ugoe/cs/autoquest/tasktrees/temporalrelation/TemporalRelationshipRuleManager.java
===================================================================
--- trunk/autoquest-core-tasktrees/src/main/java/de/ugoe/cs/autoquest/tasktrees/temporalrelation/TemporalRelationshipRuleManager.java	(revision 1189)
+++ trunk/autoquest-core-tasktrees/src/main/java/de/ugoe/cs/autoquest/tasktrees/temporalrelation/TemporalRelationshipRuleManager.java	(revision 1294)
@@ -26,5 +26,4 @@
 import de.ugoe.cs.autoquest.tasktrees.treeifc.ITaskFactory;
 import de.ugoe.cs.autoquest.tasktrees.treeifc.ITaskInstance;
-import de.ugoe.cs.autoquest.tasktrees.treeifc.ITaskInstanceList;
 import de.ugoe.cs.autoquest.tasktrees.treeifc.IUserSession;
 import de.ugoe.cs.util.console.Console;
@@ -38,9 +37,9 @@
  * between tasks which are not only a major sequence. I.e. through the application of the
  * rules iterations and selections of tasks are detected. Which kind of temporal relations
  * between tasks are detected depends on the {@link ITaskInstanceListScopeRule}s known to
  * this class.
  * </p>
  * <p>The class holds references to the appropriate {@link ITaskInstanceListScopeRule}s and calls
  * their {@link ITaskInstanceListScopeRule#apply(ITask, ITaskBuilder, ITaskFactory, boolean)}
  * method for each task in the task tree it is needed for. The general behavior of this class is
  * the following:
@@ -56,5 +55,5 @@
  *   <li>
  *     the class iterates its internal list of rules and calls their
- *     {@link ITaskInstanceListScopeRule#apply(ITask, ITaskBuilder, ITaskFactory, boolean)}
+ *     {@link ITaskInstanceScopeRule#apply(ITask, ITaskBuilder, ITaskFactory, boolean)}
  *     method.
  *   </li>
@@ -115,5 +114,5 @@
      * </p>
      */
-    private ITaskInstanceListScopeRule[] taskScopeRules;
+    private ITaskInstanceScopeRule[] taskScopeRules;
 
     /**
@@ -166,5 +165,5 @@
         //treeScopeRules.add(new DefaultGuiElementSequenceDetectionRule(frameFilter));
 
-        taskScopeRules = new ITaskInstanceListScopeRule[] {
+        taskScopeRules = new ITaskInstanceScopeRule[] {
             //new SequenceOnGuiElementDetectionRule(taskFactory, taskTreeBuilder),
             //new EventSequenceOnSameTargetDetectionRule(taskFactory, taskTreeBuilder),
@@ -262,19 +261,18 @@
      *                     on the recursion depth of calling this method.
      */
-    private int applyRules(ITaskInstanceListScopeRule[] rules,
-                           ITaskInstanceList            taskInstances,
+    private int applyRules(ITaskInstanceScopeRule[] rules,
+                           ITaskInstance                taskInstance,
                            String                       logIndent)
     {
-        Console.traceln(Level.FINER, logIndent + "applying rules for " + taskInstances.size() +
-                        " task instances");
+        Console.traceln(Level.FINER, logIndent + "applying rules on " + taskInstance);
 
         int noOfRuleApplications = 0;
 
-        for (ITaskInstanceListScopeRule rule : rules) {
+        for (ITaskInstanceScopeRule rule : rules) {
             RuleApplicationResult result;
             do {
                 Console.traceln
-                    (Level.FINER, logIndent + "trying rule " + rule + " on " + taskInstances);
-                result = rule.apply(taskInstances);
+                    (Level.FINER, logIndent + "trying rule " + rule + " on " + taskInstance);
+                result = rule.apply(taskInstance);
 
                 if ((result != null) &&
@@ -282,5 +280,5 @@
                 {
                     Console.traceln
-                        (Level.FINE, logIndent + "applied rule " + rule + " on " + taskInstances);
+                        (Level.FINE, logIndent + "applied rule " + rule + " on " + taskInstance);
                     noOfRuleApplications++;
                     
@@ -38,9 +37,9 @@
  * between tasks which are not only a major sequence. I.e. through the application of the
  * rules iterations and selections of tasks are detected. Which kind of temporal relations
- * between tasks are detected depends on the {@link ITaskInstanceListScopeRule}s known to
+ * between tasks are detected depends on the {@link ITaskInstanceScopeRule}s known to
  * this class.
  * </p>
@@ -38,9 +37,9 @@
  * this class.
  * </p>
- * <p>The class holds references to the appropriate {@link ITaskInstanceListScopeRule}s and calls
- * their {@link ITaskInstanceListScopeRule#apply(ITask, ITaskBuilder, ITaskFactory, boolean)}
+ * <p>The class holds references to the appropriate {@link ITaskInstanceScopeRule}s and calls
+ * their {@link ITaskInstanceScopeRule#apply(ITask, ITaskBuilder, ITaskFactory, boolean)}
  * method for each task in the task tree it is needed for. The general behavior of this class is
  * the following:
